/*
 * Copyright © 2016 Yong Bakos
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT.  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include <assert.h>

#include "wayland-client.h"
#include "wayland-private.h"
#include "test-runner.h"

TEST(interface_equal)
{
	const struct wl_interface fake = {
		"fake", 1, 0, NULL, 0, NULL
	};
	const struct wl_interface fake_registry = {
		"wl_registry", 1, 0, NULL, 0, NULL
	};
	const struct wl_interface copy = wl_registry_interface;

	assert(&wl_registry_interface != &copy);

	assert(wl_interface_equal(&wl_registry_interface,
				  &wl_registry_interface));
	assert(wl_interface_equal(&wl_registry_interface, &copy));
	assert(wl_interface_equal(&wl_registry_interface,
				  &fake_registry));
	assert(!wl_interface_equal(&wl_registry_interface, &fake));
}
